@@ -1,6 +1,6 @@
 package JE::Number;
 
-our $VERSION = '0.028';
+our $VERSION = '0.029';
 
 use strict;
 use warnings; no warnings 'utf8';
@@ -49,7 +49,8 @@ use overload fallback => 1,
 		my $value = $_[0][0];
 		$value && $value == $value;
 	 },
-	 cmp  =>  sub { "$_[0]" cmp $_[1] };
+#	 cmp  =>  sub { "$_[0]" cmp $_[1] };
+;
 
 use Scalar::Util qw 'blessed tainted';
 
